@@ -2,7 +2,7 @@ from retrying import RetryError, retry
 import requests
 from loguru import logger
 from constant import *
-import global_val
+import PaperCrawlerUtil.global_val as global_val
 from fake_headers import Headers
 import time
 
